==> afdiankit-0.1.0.tar.gz: afdiankit-0.1.0/afdiankit/open/__init__.py <==
from typing import TYPE_CHECKING, Dict, Literal, Optional

from pydantic import BaseModel, TypeAdapter
from afdiankit.utils import UNSET, exclude_unset

from .utils import sign as sign
from .types import (
    Ping,
    QueryOrder,
    QuerySponsor,
    PostPingRequestBody,
    PostQueryOrderRequestBody,
    PostQuerySponsorRequestBody,
)

if TYPE_CHECKING:
    from afdiankit import AfdianCore


class OpenClient:
    def __init__(self, afdian: "AfdianCore"):
        self._afdian = afdian

    def post_ping(
        self,
        *,
        headers: Optional[Dict[str, str]] = None,
        data: Literal[UNSET] = UNSET,
        **kwargs,
    ):
        url = "https://afdian.net/api/open/ping"
        if not kwargs:
            kwargs = UNSET

        json = kwargs if data is UNSET else data
        json = TypeAdapter(PostPingRequestBody).validate_python(json)
        json = json.model_dump(by_alias=True) if isinstance(json, BaseModel) else json

        return self._afdian.request(
            "POST",
            url,
            json=exclude_unset(json),
            headers=exclude_unset(headers),
            response_model=Ping,
        )

    def post_query_order(
        self,
        *,
        headers: Optional[Dict[str, str]] = None,
        data: Literal[UNSET] = UNSET,
        **kwargs,
    ):
        url = "https://afdian.net/api/open/query-order"

        if not kwargs:
            kwargs = UNSET

        json = kwargs if data is UNSET else data
        json = TypeAdapter(PostQueryOrderRequestBody).validate_python(json)
        json = json.model_dump(by_alias=True) if isinstance(json, BaseModel) else json

        return self._afdian.request(
            "POST",
            url,
            json=exclude_unset(json),
            headers=exclude_unset(headers),
            response_model=QueryOrder,
        )

    def post_query_sponsor(
        self,
        *,
        headers: Optional[Dict[str, str]] = None,
        data: Literal[UNSET] = UNSET,
        **kwargs,
    ):
        url = "https://afdian.net/api/open/query-sponsor"

        if not kwargs:
            kwargs = UNSET

        json = kwargs if data is UNSET else data
        json = TypeAdapter(PostQuerySponsorRequestBody).validate_python(json)
        json = json.model_dump(by_alias=True) if isinstance(json, BaseModel) else json

        return self._afdian.request(
            "POST",
            url,
            json=exclude_unset(json),
            headers=exclude_unset(headers),
            response_model=QuerySponsor,
        )

==> afdiankit-0.2.0.tar.gz: afdiankit-0.2.0/afdiankit/open/__init__.py <==
from typing import TYPE_CHECKING, Dict, Literal, Optional

from pydantic import BaseModel, TypeAdapter

from afdiankit.utils import UNSET, exclude_unset

from .utils import sign as sign
from .types import (
    PongResponse,
    QueryOrderResponse,
    PostPingRequestBody,
    QuerySponsorResponse,
    PostQueryOrderRequestBody,
    PostQuerySponsorRequestBody,
)

if TYPE_CHECKING:
    from afdiankit import AfdianCore


class OpenClient:
    def __init__(self, afdian: "AfdianCore"):
        self._afdian = afdian

    def post_ping(
        self,
        *,
        headers: Optional[Dict[str, str]] = None,
        data: Literal[UNSET] = UNSET,
        **kwargs,
    ):
        url = "https://afdian.net/api/open/ping"
        if not kwargs:
            kwargs = UNSET

        json = kwargs if data is UNSET else data
        json = TypeAdapter(PostPingRequestBody).validate_python(json)
        json = json.model_dump(by_alias=True) if isinstance(json, BaseModel) else json

        return self._afdian.request(
            "POST",
            url,
            json=exclude_unset(json),
            headers=exclude_unset(headers),
            response_model=PongResponse,
        )

    def post_query_order(
        self,
        *,
        headers: Optional[Dict[str, str]] = None,
        data: Literal[UNSET] = UNSET,
        **kwargs,
    ):
        url = "https://afdian.net/api/open/query-order"

        if not kwargs:
            kwargs = UNSET

        json = kwargs if data is UNSET else data
        json = TypeAdapter(PostQueryOrderRequestBody).validate_python(json)
        json = json.model_dump(by_alias=True) if isinstance(json, BaseModel) else json

        return self._afdian.request(
            "POST",
            url,
            json=exclude_unset(json),
            headers=exclude_unset(headers),
            response_model=QueryOrderResponse,
        )

    def post_query_sponsor(
        self,
        *,
        headers: Optional[Dict[str, str]] = None,
        data: Literal[UNSET] = UNSET,
        **kwargs,
    ):
        url = "https://afdian.net/api/open/query-sponsor"

        if not kwargs:
            kwargs = UNSET

        json = kwargs if data is UNSET else data
        json = TypeAdapter(PostQuerySponsorRequestBody).validate_python(json)
        json = json.model_dump(by_alias=True) if isinstance(json, BaseModel) else json

        return self._afdian.request(
            "POST",
            url,
            json=exclude_unset(json),
            headers=exclude_unset(headers),
            response_model=QuerySponsorResponse,
        )
